; 
; ZX81+LAMBDA 8300 CHARACTER SET VIRTUAL KEYCODES
; VERSION 1.0a -- 2022.08.07
;                 changes:
;                         * L83_QMARK invalidated (was incorrect at 0Bh which is QUOTE, not QMARK)
;                         GRAPHICS characters
;                         * 0Ah ZX_GRAY_N symbol corrected
;                         * 8Bh corrected to ZX_INV_QUOTE
;                         * change SHIFT x to GRAPHICS-SHIFT x
;
;[FASMW-ZX: PRESS ALT+9 TO ENABLE DISPLAY OF ZX CHARACTER SET]
;
; 00-3F PRINTABLE CHARACTERS
; 40-7F LOW TOKENS (7E=NUMBER CONTAINER FOLLOWED BY FIVE BYTES OF DATA)
; 80-BF INVERSE CHARACTERS
; C0-FF HIGH TOKENS
;
;LAMBDA 8300 keyboard
;  ? 8300.rom uses same keyboard layout as ZX81?
;  Lambda.rom
;
;LAMBDA 8300 characters
; same as ZX81: numeral 0-9, alphabet A-Z, most punctation and all black/white graphics chars
;   but the ZX81 gray (shaded) graphics chars are re-mapped to new glyphs for the LAMBDA
; "gaming chars" added: Alien, Ghost, Spider
; : not supported (0Eh ZX81 colon maps to LAMBDA Alien)
; ? not supported (0Fh ZX81 question mark maps to LAMBDA Ghost)
;  not supported (0Ch ZX81 British Pound sign maps to LAMBDA Spider)
;
;00h-0Fh graphics characters
;88h-8Fh inverted graphics characters
;
;        ZX81              LAMBDA
; 08/88= gray square     Racecar
; 09/89= gray south bar  RH diagonal triangle
; 0A/8A= gray north bar  LH diagonal triangle
; 0C/8C= pound-sterling  Spider
; 0E/8E= colon           Alien/Summer Bird
; 0F/8F= question-mark   Ghost
;
;LAMBDA 8300 TOKENS
; not supported
;   "" double-quote [instead, type two quotes]
;
;LOW TOKENS differ
;40-42 ZX81    LAMBDA
;      RND     ' THEN ;(moved from DE-E0)
;      INKEY$  ' TO '
;      PI      ' STEP '
;NEW UPPER-LOW TOKENS ADDED
;43-48 ZX81    LAMBDA
;      unused  'RND'     (Lambda moves these +3)
;              'INKEY$'
;              'PI'
;              ' INK '    (new tokens for Lambda)
;              ' PAPER '
;              ' BORDER '
; HIGH TOKEN differ
; C0-C4 ZX81   LAMBDA
;       ""     not used by Lambda
;       AT     Lambda moves it to D4
;       TAB                       D5
;       unused
; C5-D3 subtract -4 for Lambda tokens
; D4-D5 add     +19 for Lambda tokens
; D6-DB subtract -2 for Lambda tokens
;    DC >=     TEMPO
;    DD <>     MUSIC
; DE-E0 Lambda moves these to 40-42
; E1-FF same

;ZX CHARACTER SET VIRTUAL KEY CODES
;00-07 GRAPHICS CHARS
ZX_SPACE   EQU 00H  ;0	' ' SPACE
ZX_NW	   EQU 01H  ;1	'' NW DOT	   (GRAPHICS-SHIFT 1) (L83:GRAPHICS-SHIFT Q)
ZX_NE	   EQU 02H  ;2	'' NE DOT	   (GRAPHICS-SHIFT 2) (L83:GRAPHICS-SHIFT W)
ZX_NORTH   EQU 03H  ;3	'' NORTH BAR	   (GRAPHICS-SHIFT 7) (L83:GRAPHICS-SHIFT X)
ZX_SW	   EQU 04H  ;4	'' SW DOT	   (GRAPHICS-SHIFT 4) (L83:GRAPHICS-SHIFT E)
ZX_WEST    EQU 05H  ;5	'' WEST BAR	   (GRAPHICS-SHIFT 5) (L83:GRAPHICS-SHIFT C)
ZX_NE_CHK  EQU 06H  ;6	'' NE CHECKER	   (GRAPHICS-SHIFT T) (L83:GRAPHICS-SHIFT B)
ZX_INV_SE  EQU 07H  ;7	'' INVERSE SE DOT (GRAPHICS-SHIFT 3) (L83:GRAPHICS-SHIFT I)

;08-0F GRAPHICS CHARS (LAMBDA DIFFERS). The ZX81 has are 20 keys printed with dedicated graphics symbols. The 8300 has 22 keys with graphics symbols
L83_CAR    EQU 08H  ;8	RACE CAR	   (GRAPHICS-SHIFT A) (ZX81:)
L83_NW_TRI EQU 09H  ;9	NW TRIANGLE	   (GRAPHICS-SHIFT D) (ZX81:)
L83_NE_TRI EQU 0AH  ;10 NE TRIANGLE	   (GRAPHICS-SHIFT S) (ZX81:)
;          EQU 0BH  ;11 QUOTATION MARK SAME AS ZX81
L83_QMARK  EQU QUOTE OR ?-MARK		;L83_QMARK IS AMBIGUOUS (but was included in first version)
L83_SPIDER EQU 0CH  ;12 SPIDER GAMING CHAR (GRAPHICS-SHIFT 2) (ZX81:)
L83_DOLLAR EQU 0DH  ;13 '$' DOLLAR SIGN    (SHIFT 4)	      (ZX81:TO)
L83_ALIEN  EQU 0EH  ;14 ALIEN GAMING CHAR  (GRAPHICS-SHIFT 3) (ZX81:)
L83_GHOST  EQU 0FH  ;15 GHOST GAMING CHAR  (GRAPHICS-SHIFT 1) (ZX81:)
;   ZX81
ZX_GRAY    EQU 08H  ;8	'' GRAY SQUARE    (GRAPHICS-SHIFT A)
ZX_GRAY_S  EQU 09H  ;9	'' GRAY SOUTH BAR (GRAPHICS-SHIFT D)
ZX_GRAY_N  EQU 0AH  ;10 '' GRAY NORTH BAR (GRAPHICS-SHIFT S)
ZX_QUOTE   EQU 0BH  ;11 '"' QUOTATION MARK (SHIFT P)
ZX_SHIFT_P EQU 0BH  ;	'"' QUOTATION MARK (SHIFT P)
ZX_POUND   EQU 0CH  ;12 '' BRITISH POUND  (SHIFT SPACE)
ZX_DOLLAR  EQU 0DH  ;13 '$' DOLLAR SIGN    (SHIFT U)
ZX_COLON   EQU 0EH  ;14 ':' COLON SIGN	   (SHIFT Z)
ZX_QMARK   EQU 0FH  ;15 '?' QUESTION MARK  (SHIFT C)
ZX_SHIFT_C EQU 0FH  ;	'?' SHIFT C	   (QUESTION MARK)

; 10-1B PUNCTUATION
ZX_LPAR    EQU 10H  ;16 '(' LEFT PAREN	   (SHIFT I)
ZX_RPAR    EQU 11H  ;17 ')' RIGHT PAREN    (SHIFT O)
ZX_GT	   EQU 12H  ;18 '>' GREATER THAN   (SHIFT M)
ZX_LT	   EQU 13H  ;19 '<' LESS THAN	   (SHIFT N)
ZX_EQUAL   EQU 14H  ;20 '=' EQUAL SIGN	   (SHIFT L)
ZX_SHIFT_L EQU 14H  ;	'=' SHIFT L	   (EQUAL SIGN)
ZX_PLUS    EQU 15H  ;21 '+' PLUS SIGN	   (SHIFT K)
ZX_MINUS   EQU 16H  ;22 '-' MINUS SIGN	   (SHIFT J)
ZX_SHIFT_J EQU 16H  ;	'-' SHIFT J	   (MINUS SIGN)
ZX_HYPHEN  EQU 16H  ;	'-' HIPHEN	   (SHIFT J)
ZX_ASTER   EQU 17H  ;23 '*' ASTERISK	   (SHIFT B)
ZX_SLASH   EQU 18H  ;24 '/' SLASH	   (SHIFT V)
ZX_SHIFT_V EQU 18H  ;	'/' SHIFT V	   (SLASH)
ZX_SEMI    EQU 19H  ;25 ';' SEMICOLON	   (SHIFT X)
ZX_COMMA   EQU 1AH  ;26 ',' COMMA	   (SHIFT .)
ZX_PERIOD  EQU 1BH  ;27 '.' PERIOD
; 1C-25 NUMERALS 0-9
ZX_0	   EQU 1CH  ;28 '0'
ZX_1	   EQU 1DH  ;29 '1'
ZX_2	   EQU 1EH  ;30 '2'
ZX_3	   EQU 1FH  ;31 '3'
ZX_4	   EQU 20H  ;32 '4'
ZX_5	   EQU 21H  ;33 '5'
ZX_6	   EQU 22H  ;34 '6'
ZX_7	   EQU 23H  ;35 '7'
ZX_8	   EQU 24H  ;36 '8'
ZX_9	   EQU 25H  ;37 '9'
; 26-3F ALPHABET A-Z
ZX_9_PLUS  EQU 26H  ;	NEXT CHAR AFTER '9' (ZX81'A' ASCII';')
ZX_A	   EQU 26H  ;38 'A'
ZX_B	   EQU 27H  ;39 'B'
ZX_C	   EQU 28H  ;40 'C'
ZX_D	   EQU 29H  ;41 'D'
ZX_E	   EQU 2AH  ;42 'E'
ZX_F	   EQU 2BH  ;43 'F'
ZX_F_PLUS  EQU 2CH  ; NEXT CHAR AFTER 'F' (G)
ZX_G	   EQU 2CH  ;44 'G'
ZX_H	   EQU 2DH  ;45 'H'
ZX_I	   EQU 2EH  ;56 'I'
ZX_J	   EQU 2FH  ;47 'J'
ZX_K	   EQU 30H  ;48 'K'
ZX_L	   EQU 31H  ;49 'L'
ZX_M	   EQU 32H  ;50 'M'
ZX_N	   EQU 33H  ;51 'N'
ZX_O	   EQU 34H  ;52 'O'
ZX_P	   EQU 35H  ;53 'P'
ZX_Q	   EQU 36H  ;54 'Q'
ZX_R	   EQU 37H  ;55 'R'
ZX_S	   EQU 38H  ;56 'S'
ZX_T	   EQU 39H  ;57 'T'
ZX_U	   EQU 3AH  ;58 'U'
ZX_V	   EQU 3BH  ;59 'V'
ZX_W	   EQU 3CH  ;60 'W'
ZX_X	   EQU 3DH  ;61 'X'
ZX_Y	   EQU 3EH  ;62 'Y'
ZX_Z	   EQU 3FH  ;63 'Z'
; 40-42 LOW TOKENS
ZX_RND	   EQU 40H  ;64 'RND'	 (FUNCTION T)
ZX_INKEY   EQU 41H  ;65 'INKEY$' (FUNCTION B)
ZX_PI	   EQU 42H  ;66 'PI'	 (FUNCTION M)
;   OFFSET -158
L83_THEN   EQU 40H  ;64 ' THEN ' [ZX81:RND   ,ZX_THEN-158]
L83_TO	   EQU 41H  ;65 ' TO '	 [ZX81:INKEY$,ZX_TO-158]
L83_STEP   EQU 42H  ;66 ' STEP ' [ZX81:STEP  ,ZX_STEP-158]
; 43-48 LAMBDA TOKENS
L83_RND    EQU 43H  ;67 'RND'	  [ZX81:undefined]
L83_INKEY  EQU 44H  ;68 'INKEY$'  [ZX81:undefined]
L83_PI	   EQU 45H  ;69 'PI'	  [ZX81:undefined]
L83_INK    EQU 46H  ;70 ' INK '   [ZX81:undefined]
L83_PAPER  EQU 47H  ;71 ' PAPER ' [ZX81:undefined]
L83_BORDER EQU 48H  ;72 ' BORDER '[ZX81:undefined]
; 43-6F UNUSED ZX81
; 70-79 CONTROL CODES
ZX_U_ARROW EQU 70H  ;112 CURSOR UP    (SHIFT 7)
ZX_D_ARROW EQU 71H  ;113 CURSOR DOWN  (SHIFT 6)
ZX_L_ARROW EQU 72H  ;114 CURSOR LEFT  (SHIFT 5)
ZX_R_ARROW EQU 73H  ;115 CURSOR RIGHT (SHIFT 8)
ZX_GRAPHIC EQU 74H  ;116 GRAPHICS     (SHIFT 9)
ZX_SHIFT_1 EQU 75H  ;117 'EDIT'       (SHIFT 1)
ZX_EDIT    EQU 75H  ;117 'EDIT'       (SHIFT 1)
ZX_NEWLINE EQU 76H  ;118 NEWLINE/ENTER KEY
ZX_EOL	   EQU $76  ;118 NEWLINE/END OF LINE
ZX_SHIFT_0 EQU 77H  ;119 'RUBOUT'    (SHIFT 0)
ZX_RUBOUT  EQU 77H  ;119 'RUBOUT'    (SHIFT 0)
ZX_DELETE  EQU 77H  ;119 DELETE/RUBOUT (SHIFT 0)
ZX_KL	   EQU 78H  ;120 K/L MODE
ZX_FUNC    EQU 79H  ;121 FUNCTION (SHIFT NEWLINE)
L83_BREAK  EQU 79H  ;		  (SHIFT SPACE)
;7A-7D UNUSED ZX81
L83_LINENO EQU 7AH
ZX_NUMBER  EQU 7EH  ;126 NUMBER CONTAINER MARKER
ZX_CURSOR  EQU 7FH  ;127 CURSOR
;80-87 GRAPHICS
ZX_INV_SP      EQU 80H ;128 '' INVERSE SPACE  (GRAPHICS SPACE)
ZX_INV_NW      EQU 81H ;129 '' INVERSE NW DOT (GRAPHICS-SHIFT Q)	(L83:GRAPHICS-SHIFT T)
ZX_INV_NE      EQU 82H ;130 '' INVERSE NE DOT (GRAPHICS-SHIFT W)	(L83:GRAPHICS-SHIFT Y)
ZX_SOUTH       EQU 83H ;131 '' SOUTH BAR      (GRAPHICS-SHIFT 6) (L83:GRAPHICS-SHIFT Z)
ZX_INV_SW      EQU 84H ;132 '' INVERSE SW DOT (GRAPHICS-SHIFT R) (L83:GRAPHICS-SHIFT U)
ZX_EAST        EQU 85H ;133 '' EAST BAR       (GRAPHICS-SHIFT 8) (L83:GRAPHICS-SHIFT V)
ZX_SE_CHK      EQU 86H ;134 '' SE CHECKER     (GRAPHICS-SHIFT Y) (L83:GRAPHICS-SHIFT N)
ZX_SE	       EQU 87H ;135 '' SE DOT	       (GRAPHICS-SHIFT 3) (L83:GRAPHICS-SHIFT R)

;88-8F GRAPHICS CHARS (LAMBDA DIFFERS)
L83_INV_CAR    EQU 88H ;136 INVERSE RACING CAR	       (GRAPHICS-SHIFT A)
L83_SE_TRI     EQU 89H ;137 '' INVERSE NW DOT	       (GRAPHICS-SHIFT T)
L83_SW_TRI     EQU 8AH ;138 '' INVERSE NE DOT	       (GRAPHICS-SHIFT Y)
L83_INV_QMARK  EQU 8BH ;139 '' INVERSE QUOTATION MARK (GRAPHICS-SHIFT 5)
L83_INV_SPIDER EQU 8CH ;140 INVERSE SPIDER GAMING CHAR (GRAPHICS-SHIFT 2)
L83_INV_DOLLAR EQU 8DH ;141 '' INVERSE DOLLAR SIGN
L83_INV_ALIEN  EQU 8EH ;142 INVERSE ALIEN GAMING CHAR  (GRAPHICS-SHIFT 3)
L83_INV_GHOST  EQU 8FH ;143 INVERSE GHOST GAMING CHAR  (GRAPHICS-SHIFT 1)
;   ZX81
ZX_INV_GRY     EQU 88H ;136 '' INVERSE GRAY SQUARE	(GRAPHICS-SHIFT H)
ZX_GRAY_S      EQU 89H ;137 '' INVERSE GRAY SOUTH BAR	(GRAPHICS-SHIFT G)
ZX_GRAY_N      EQU 8AH ;138 '' INVERSE GRAY NORTH BAR	(GRAPHICS-SHIFT F)
ZX_INV_QUOTE   EQU 8BH ;139 '' INVERSE QUOTATION MARK	(GRAPHICS-SHIFT P)
ZX_INV_POUND   EQU 8CH ;140 '' INVERSE POUND SIGN
ZX_INV_DOLLAR  EQU 8DH ;141 '' INVERSE DOLLAR SIGN
ZX_INV_COLON   EQU 8EH ;142 '' INVERSE COLON
ZX_INV_QMARK   EQU 8FH ;143 '' INVERSE QUESTION MARK	(GRAPHICS-SHIFT C)

;90-98 INVERSE PUNCUATION
ZX_INV_LPAR    EQU 90H	;144 '' INVERSE LEFT PARENTHESIS
ZX_INV_RPAR    EQU 91H	;145 '' INVERSE RIGHT PARENTHESIS
ZX_INV_GT      EQU 92H	;146 '' INVERSE GREATER THAN
ZX_INV_LT      EQU 93H	;147 '' INVERSE LESS THAN  (GRAPHICS-SHIFT N)
ZX_INV_EQUAL   EQU 94H	;148 '' INVERSE EQUAL SIGN (GRAPHICS-SHIFT L)
ZX_INV_SHIFT_L EQU 94H	;    '' INVERSE EQUAL SIGN (GRAPHICS-SHIFT L)
ZX_INV_PLUS    EQU 95H	;149 '' INVERSE PLUS SIGN  (GRAPHICS SHIFT K)
ZX_INV_MINUS   EQU 96H	;150 '' INVERSE MINUS	    (GRAPHICS SHIFT J)
ZX_INV_SHIFT_J EQU 96H	;    '' INVERSE HIPHEN     (GRAPHICS SHIFT J)
ZX_INV_HYPHEN  EQU 96H	;    '' INVERSE NEG. SIGN  (GRAPHICS SHIFT J)
ZX_INV_ASTER   EQU 97H	;151 '' INVERSE ASTERISK   (GRAPHICS SHIFT B)
ZX_INV_SLASH   EQU 98H	;152 '' INVERSE SLASH	    (GRAPHICS SHIFT V)
ZX_INV_SHIFT_V EQU 98H	;    '' INVERSE SHIFT V (SLASH)
ZX_INV_SEMI    EQU 99H	;153 '' INVERSE SEMICOLON  (GRAPHICS SHIFT X)
ZX_INV_COMMA   EQU 9AH	;153 '' INVERSE COMMA	    (GRAPHICS SHIFT .)
ZX_INV_PERIOD  EQU 9BH	;155 '' INVERSE PERIOD     (GRAPHICS .)
;9C-A5 INVERSE NUMERALS 0-9
ZX_INV_0   EQU 9CH  ;156 '' INVERSE 0 (GRAPHICS 0)
ZX_INV_1   EQU 9DH  ;157 '' INVERSE 1 (GRAPHICS 1)
ZX_INV_2   EQU 9EH  ;158 '' INVERSE 2 (GRAPHICS 2)
ZX_INV_3   EQU 9FH  ;159 '' INVERSE 3 (GRAPHICS 3)
ZX_INV_4   EQU 0A0H ;160 '' INVERSE 4 (GRAPHICS 4)
ZX_INV_5   EQU 0A1H ;161 '' INVERSE 5 (GRAPHICS 5)
ZX_INV_6   EQU 0A2H ;162 '' INVERSE 6 (GRAPHICS 6)
ZX_INV_7   EQU 0A3H ;163 '' INVERSE 7 (GRAPHICS 7)
ZX_INV_8   EQU 0A4H ;164 '' INVERSE 8 (GRAPHICS 8)
ZX_INV_9   EQU 0A5H ;165 '' INVERSE 9 (GRAPHICS 9)
;A6-BF INVERSE ALPHABET A-Z
ZX_INV_A   EQU 0A6H ;166 '' INVERSE A (GRAPHICS A)
ZX_INV_B   EQU 0A7H ;167 '' INVERSE B (GRAPHICS B)
ZX_INV_C   EQU 0A8H ;168 '' INVERSE C (GRAPHICS C)
ZX_INV_D   EQU 0A9H ;169 '' INVERSE D (GRAPHICS D)
ZX_INV_E   EQU 0AAH ;170 '' INVERSE E (GRAPHICS E)
ZX_INV_F   EQU 0ABH ;17A '' INVERSE F (GRAPHICS F)
ZX_INV_G   EQU 0ACH ;172 '' INVERSE G (GRAPHICS G)
ZX_INV_H   EQU 0ADH ;173 '' INVERSE H (GRAPHICS H)
ZX_INV_I   EQU 0AEH ;174 '' INVERSE I (GRAPHICS I)
ZX_INV_J   EQU 0AFH ;175 '' INVERSE J (GRAPHICS J)
ZX_INV_K   EQU 0B0H ;176 '' INVERSE K (GRAPHICS K)
ZX_INV_L   EQU 0B1H ;177 '' INVERSE L (GRAPHICS L)
ZX_INV_M   EQU 0B2H ;178 '' INVERSE M (GRAPHICS M)
ZX_INV_N   EQU 0B3H ;179 '' INVERSE N (GRAPHICS N)
ZX_INV_O   EQU 0B4H ;180 '' INVERSE O (GRAPHICS O)
ZX_INV_P   EQU 0B5H ;181 '' INVERSE P (GRAPHICS P)
ZX_INV_Q   EQU 0B6H ;182 '' INVERSE Q (GRAPHICS Q)
ZX_INV_R   EQU 0B7H ;183 '' INVERSE R (GRAPHICS R)
ZX_INV_S   EQU 0B8H ;184 '' INVERSE S (GRAPHICS S)
ZX_INV_T   EQU 0B9H ;185 '' INVERSE T (GRAPHICS T)
ZX_INV_U   EQU 0BAH ;186 '' INVERSE U (GRAPHICS U)
ZX_INV_V   EQU 0BBH ;187 '' INVERSE V (GRAPHICS V)
ZX_INV_W   EQU 0BCH ;188 '' INVERSE W (GRAPHICS W)
ZX_INV_X   EQU 0BDH ;189 '' INVERSE X (GRAPHICS X)
ZX_INV_Y   EQU 0BEH ;190 '' INVERSE Y (GRAPHICS Y)
ZX_INV_Z   EQU 0BFH ;191 '' INVERSE Z (GRAPHICS Z)
; C0-FF HIGH TOKENS (LAMBDA DIFFERS)
; LAMBDA OFFSET -4
L83_CODE   EQU 0C0H ;192 'CODE ' [ZX81:'""'   ,ZX_CODE-4]
L83_VAL    EQU 0C1H ;193 'VAL '  [ZX81:' AT ' ,ZX_VAL-4]
L83_LEN    EQU 0C2H ;194 'LEN '  [ZX81:'TAB ' ,ZX_LEN-4]
L83_SIN    EQU 0C3H ;195 'SIN '  [ZX81:not used]
L83_COS    EQU 0C4H ;196 'COS '  [ZX81:'CODE ',ZX_COS-4]
L83_TAN    EQU 0C5H ;197 'TAN '  [ZX81:'VAL ' ,ZX_TAN-4]
L83_ASN    EQU 0C6H ;198 'ASN '  [ZX81:'LEN ' ,ZX_ASN-4]
L83_ACS    EQU 0C7H ;199 'ACS '  [ZX81:'SIN ' ,ZX_ACS-4]
L83_ATN    EQU 0C8H ;200 'ATN '  [ZX81:'COS ' ,ZX_ATN-4]
L83_LOG    EQU 0C9H ;201 'LOG '  [ZX81:'TAN ' ,ZX_LOG-4]
L83_EXP    EQU 0CAH ;202 'EXP '  [ZX81:'ASN ' ,ZX_EXP-4]
L83_INT    EQU 0CBH ;203 'INT '  [ZX81:'ACS ' ,ZX_INT-4]
L83_SQR    EQU 0CCH ;204 'SQR '  [ZX81:'ATN ' ,ZX_SQR-4]
L83_SGN    EQU 0CDH ;205 'SGN '  [ZX81:'LN '  ,ZX_SGN-4]
L83_ABS    EQU 0CEH ;206 'ABS '  [ZX81:'EXP ' ,ZX_ABS-4]
L83_PEEK   EQU 0CFH ;207 'PEEK ' [ZX81:'INT ' ,ZX_PEEK-4]
L83_USR    EQU 0D0H ;208 'USR '  [ZX81:'SQR ' ,ZX_USR-4]
L83_STR    EQU 0D1H ;209 'STR$ ' [ZX81:'SGN ' ,ZX_STR-4]
L83_CHR    EQU 0D2H ;210 'CHR$ ' [ZX81:'CHR$ ',ZX_CHR-4]
L83_NOT    EQU 0D3H ;211 'NOT '  [ZX81:'PEEK ',ZX_NOT-4]
; OFFSET +19
L83_AT	   EQU 0D4H ;212 ' AT '  [ZX81:'USR ' ,ZX_AT+19]
L83_TAB    EQU 0D5H ;213 'TAB '  [ZX81:'STR$ ',ZX_TAB+19]
; OFFSET -2
L83_POWER  EQU 0D6H ;214 '**'	 [ZX81:'CHR$ ',ZX_POWER-2] DOUBLE ASTERISK
L83_OR	   EQU 0D7H ;215 ' OR '  [ZX81:'NOT ' ,ZX_OR-2]
L83_AND    EQU 0D8H ;216 ' AND ' [ZX81:'**'   ,ZX_AND-2]
L83_LTE    EQU 0D9H ;217 '<='	 [ZX81:' OR ' ,ZX_LTE-2]
L83_GTE    EQU 0DAH ;218 '>='	 [ZX81:' AND ',ZX_GTE-2]
L83_NOTEQU EQU 0DBH ;219 '<>'	 [ZX81:'<='   ,ZX_NOTEQU-2]
;LAMBDA UNIQUE TOKENS
L83_TEMPO  EQU 0DCH ;220 ' TEMPO '[ZX81 '>=']
L83_MUSIC  EQU 0DDH ;221 ' MUSIC '[ZX81 '<>']
L83_SOUND  EQU 0DEH ;222 ' SOUND '[ZX81 'THEN']
L83_BEEP   EQU 0DFH ;223 ' BEEP ' [ZX81 'TO']
L83_NOBEEP EQU 0E0H ;224 ' NOBEEP '[ZX81 'STEP']
;ZX81 HIGH-LOWER TOKENS (DIFFERS FROM LAMBDA)
ZX_DBL_QT  EQU 0C0H ;192 '""'	(SHIFT Q) DOUBLE QUOTE MARKS
ZX_AT	   EQU 0C1H ;193 ' AT ' (FUNCTION C)
ZX_TAB	   EQU 0C2H ;194 'TAB ' (FUNCTION P)
ZX_C3	   EQU 0C3H ;195 ZX81:undefined/not used
ZX_CODE    EQU 0C4H ;196 'CODE '(FUNCTION I)
ZX_VAL	   EQU 0C5H ;197 'VAL ' (FUNCTION J)
ZX_LEN	   EQU 0C6H ;198 'LEN ' (FUNCTION K)
ZX_SIN	   EQU 0C7H ;199 'SIN ' (FUNCTION Q)
ZX_COS	   EQU 0C8H ;200 'COS ' (FUNCTION W)
ZX_TAN	   EQU 0C9H ;201 'TAN ' (FUNCTION E)
ZX_ASN	   EQU 0CAH ;202 'ASN ' (FUNCTION A) ARCSIN
ZX_ACS	   EQU 0CBH ;203 'ACS ' (FUNCTION S) ARCCOS
ZX_ATN	   EQU 0CCH ;204 'ATN ' (FUNCTION D) ARCTAN
ZX_LN	   EQU 0CDH ;205 'LN'	(FUNCTION Z) Natural Logarithm
ZX_EXP	   EQU 0CEH ;206 'EXP ' (FUNCTION X) Exponential function
ZX_INT	   EQU 0CFH ;207 'INT ' (FUNCTION R) Integer function
ZX_SQR	   EQU 0D0H ;208 'SQR ' (FUNCTION H) Square Root function
ZX_SGN	   EQU 0D1H ;209 'SGN ' (FUNCTION F) Sign function/Signum
ZX_ABS	   EQU 0D2H ;210 'ABS ' (FUNCTION G) Absolute Value/Modulus
ZX_PEEK    EQU 0D3H ;211 'PEEK '(FUNCTION O)
ZX_USR	   EQU 0D4H ;212 'USR ' (FUNCTION L)
ZX_STR	   EQU 0D5H ;213 'STR$ '(FUNCTION Y)
ZX_CHR	   EQU 0D6H ;214 'CHR$ '(FUNCTION U)
ZX_NOT	   EQU 0D7H ;215 'NOT ' (FUNCTION N)
ZX_POWER   EQU 0D8H ;216 '**'	(SHIFT H) EXPONENT/POWER OF
ZX_OR	   EQU 0D9H ;217 ' OR ' (SHIFT W)
ZX_AND	   EQU 0DAH ;218 ' AND '(SHIFT 2)
ZX_SHIFT_R EQU 0DBH ;219 '<='	(SHIFT R) LESS THAN OR EQUAL
ZX_LTE	   EQU 0DBH ;219 '<='	(SHIFT R) LESS THAN OR EQUAL
ZX_GTE	   EQU 0DCH ;220 '>='	(SHIFT Y) GREATER THAN OR EQUAL
ZX_NOTEQU  EQU 0DDH ;221 '<>'	(SHIFT T) NOT EQUAL
ZX_THEN    EQU 0DEH ;222 ' THEN '(SHIFT 3)
ZX_TO	   EQU 0DFH ;223 ' TO '  (SHIFT 4)
ZX_STEP    EQU 0E0H ;224 ' STEP '(SHIFT E)
ZX_SHIFT_E EQU 0E0H ;224 ' STEP '(SHIFT E)

;E1-FF HIGH-UPPER TOKENS SAME ZX81 & LAMBDA (BUT LAMBDA KEYBOARD LAYOUT DIFFERS)
ZX_LPRINT  EQU 0E1H ;225 ' LPRINT '(SHIFT S)
ZX_SHIFT_S EQU 0E1H ;	 ' LPRINT '(SHIFT S)
ZX_LLIST   EQU 0E2H ;226 ' LLIST ' (SHIFT G)
ZX_STOP    EQU 0E3H ;227 ' STOP '  (SHIFT A)
ZX_SLOW    EQU 0E4H ;228 ' SLOW '  (SHIFT D)
ZX_SHIFT_D EQU 0E4H ;	 ' SLOW '  (SHIFT D)
ZX_FAST    EQU 0E5H ;229 ' FAST '  (SHIFT F)
ZX_NEW	   EQU 0E6H ;230 ' NEW '   (KEYWORD A)
ZX_SCROLL  EQU 0E7H ;231 ' SCROLL '(KEYWORD B)
ZX_CONT    EQU 0E8H ;232 ' CONT '  (KEYWORD C)
ZX_DIM	   EQU 0E9H ;233 ' DIM '   (KEYWORD D)
ZX_REM	   EQU 0EAH ;234 ' REM '   (KEYWORD E)
ZX_FOR	   EQU 0EBH ;235 ' FOR '   (KEYWORD F)
ZX_GOTO    EQU 0ECH ;236 ' GOTO '  (KEYWORD G)
ZX_GOSUB   EQU 0EDH ;237 ' GOSUB ' (KEYWORD H)
ZX_INPUT   EQU 0EEH ;238 ' INPUT ' (KEYWORD I)
ZX_LOAD    EQU 0EFH ;239 ' LOAD '  (KEYWORD J)
ZX_LIST    EQU 0F0H ;240 ' LIST '  (KEYWORD K)
ZX_LET	   EQU 0F1H ;241 ' LET '   (KEYWORD L)
ZX_PAUSE   EQU 0F2H ;242 ' PAUSE ' (KEYWORD M)
ZX_NEXT    EQU 0F3H ;243 ' NEXT '  (KEYWORD N)
ZX_POKE    EQU 0F4H ;244 ' POKE '  (KEYWORD O)
ZX_PRINT   EQU 0F5H ;245 ' PRINT ' (KEYWORD P)
ZX_PLOT    EQU 0F6H ;246 ' PLOT '  (KEYWORD Q)
ZX_RUN	   EQU 0F7H ;247 ' RUN '   (KEYWORD R)
ZX_SAVE    EQU 0F8H ;248 ' SAVE '  (KEYWORD S)
ZX_RAND    EQU 0F9H ;249 ' RAND '  (KEYWORD T)
ZX_IF	   EQU 0FAH ;250 ' IF '    (KEYWORD U)
ZX_CLS	   EQU 0FBH ;251 ' CLS '   (KEYWORD V)
ZX_UNPLOT  EQU 0FCH ;252 ' UNPLOT' (KEYWORD W)
ZX_CLEAR   EQU 0FDH ;253 ' CLEAR ' (KEYWORD X)
ZX_RETURN  EQU 0FEH ;254 ' RETURN '(KEYWORD Y)
ZX_COPY    EQU 0FFH ;255 ' COPY '  (KEYWORD Z)